********************************
* G. Schneider and F. Genovese *
*      "Smoke with Fire"       *
*      Replication Do File     *
********************************

use "../20121001SmokeWithFire.dta"

gen interactiondebtbank = crisisfivebank*cumulateddebtlagged
gen interactiondebtcurr = crisisfivecurr*cumulateddebtlagged
gen interactionbankcurr = crisisfivebank*crisisfivecurr
gen interactiondebtbankcurr = crisisfivebank*crisisfivecurr*cumulateddebtlagged

*** Models ***



* Table 1: Linear regressions of central bank independence
eststo M1a: xtreg x100change cumulateddebtlagged, fe
eststo M1b: xtreg x100change crisisfivebank, fe
eststo M1c: xtreg x100change crisisfivecurr, fe
eststo M2: xtreg x100change cumulateddebtlagged crisisfivebank interactiondebtbank, fe
eststo M3: xtreg x100change cumulateddebtlagged crisisfivecurr interactiondebtcurr, fe
eststo M4: xtreg x100change crisisfivebank crisisfivecurr interactionbankcurr, fe
eststo M5: xtreg x100change cumulateddebtlagged crisisfivebank crisisfivecurr interactiondebtbankcurr, fe
estimates table M1a M1b M1c M2 M3 M4 M5, star stats (N r2)
*esttab M1a M1b M1c M2 M3 M4 using Table1.doc

* Table 2.A: Logit regressions of democratization
eststo N1a: xtlogit democratizationpolity cumulateddebtlagged, fe
eststo N1b: xtlogit democratizationpolity crisisfivebank, fe
eststo N1c: xtlogit democratizationpolity crisisfivecurr, fe
eststo N2: xtlogit democratizationpolity cumulateddebtlagged  crisisfivebank interactiondebtbank, fe
eststo N3: xtlogit democratizationpolity cumulateddebtlagged crisisfivecurr interactiondebtcurr, fe
eststo N4: xtlogit democratizationpolity crisisfivebank crisisfivecurr interactionbankcurr, fe
eststo N5: xtlogit democratizationpolity cumulateddebtlagged crisisfivebank crisisfivecurr interactiondebtbankcurr, fe
estimates table N1a N1b N1c N2 N3 N4 N5, star stats (N chi2)
*esttab N1a N1b N1c N2 N3 N4 using democratizationFE.doc

* Table 2.B: Logit regressions of autocratization
eststo P1a: xtlogit autocratizationpolity cumulateddebtlagged, fe
eststo P1b: xtlogit autocratizationpolity crisisfivebank, fe
eststo P1c: xtlogit autocratizationpolity crisisfivecurr, fe
eststo P2: xtlogit autocratizationpolity cumulateddebtlagged  crisisfivebank interactiondebtbank, fe
eststo P3: xtlogit autocratizationpolity cumulateddebtlagged crisisfivecurr interactiondebtcurr, fe
eststo P4: xtlogit autocratizationpolity crisisfivebank crisisfivecurr interactionbankcurr, fe
eststo P5: xtlogit autocratizationpolity cumulateddebtlagged crisisfivebank crisisfivecurr interactiondebtbankcurr, fe
estimates table P1a P1b P1c P2 P3 P4, star stats (N chi2)
*esttab P1a P1b P1c P2 P3 P4 using autocratizationFE.doc



*** Graphs ***

* Figure 1.A Relation of CBI and cumulated debt
mkspline debtspl 19 = cumulateddebtlagged , dis 
xtreg x100change debtspl* , fe cluster(_ISO3N_)
drop if cumulateddebtlagged>1800

predict yhat 
predict se, stdp 
gen lb = yhat - 1.96*se 
gen ub = yhat + 1.96*se 
twoway rarea lb ub cumulateddebtlagged, sort ||  line yhat cumulateddebtlagged, sort ///
title("Relation between CBI change and cumulated debt") ///
ytitle("CBI change") ///
xtitle("cumulated debt (lagged)") 

* Figure 1.B Relation of CBI and interaction debt*banking crisis
mkspline interactionspl 20 = interactiondebtbank , dis 
xtreg x100change cumulateddebtlagged crisisfivebank interactionspl*, fe cluster(_ISO3N_)
drop if interactiondebtbank>1800
predict yhat 
predict se, stdp 
gen lb = yhat - 1.96*se 
gen ub = yhat + 1.96*se 
*drop interactionspl that are above 10
twoway rarea lb ub interactiondebtbank, sort ||  line yhat interactiondebtbank, sort ///
title("Relation between CBI change and debt") ///
ytitle("CBI change") ///
xtitle("Cumulated debt*banking crisis interaction")



* Figure 2.A Marginal effect graph of banking crisis on autocratization (debt on the axis)

estsimp logit autocratizationpolity cumulateddebtlagged crisisfivebank  interactiondebtbank,  sims(10000)
setx	
generate ploLr = .
generate phiLr = .			
generate Lr = .

generate ploHr = .
generate phiHr = .
generate Hr = .

generate debtaxis =((_n-1)/50) in 1/51
	
local a = 0
while `a' <= 1  {
setx crisisfivebank `a' cumulateddebtlagged mean interactiondebtbank `a'*107.72
simqi, pr genpr(auto0 auto1)

_pctile auto0, p(2.5,97.5)
replace ploLr = r(r1) if debtaxis ==`a'
replace phiLr = r(r2) if debtaxis ==`a'
replace Lr = auto0 if debtaxis ==`a'

_pctile auto1, p(2.5,97.5)
replace ploHr = r(r1) if debtaxis ==`a'
replace phiHr = r(r2) if debtaxis ==`a'
replace Hr = auto1 if debtaxis ==`a'

drop auto0-auto1

local a = `a' + 0.01
}
sort debtaxis


graph twoway line Hr debtaxis, clwidth(medium) clcolor(blue) /*
*/ || line ploHr debtaxis, clpattern(dash) clwidth(thin) clcolor(black) /*
*/ || line phiHr debtaxis, clpattern(dash) clwidth(thin) clcolor(black)/* 
*/ ytitle(Pr) xtitle("") /*
*/ title("Marginal effect of Banking crisis over Autocratization as Debt changes", size(4))

/*
graph twoway line Lr debtaxis, clwidth(medium) clcolor(blue) /*
*/ || line ploLr debtaxis, clpattern(dash) clwidth(thin) clcolor(black) /*
*/ || line phiLr debtaxis, clpattern(dash) clwidth(thin) clcolor(black)/* 
*/ ytitle(Pr) xtitle("") /*
*/ title("Marginal effect of Banking crisis over non-autocratization as Debt changes", size(4)) 



* Figure 2.B Marginal effect graph of banking crisis on democratization (debt on the axis)
estsimp logit democratizationpolity cumulateddebtlagged crisisfivebank  interactiondebtbank,  sims(10000)
setx
generate ploLr = .
generate phiLr = .			
generate Lr = .

generate ploHr = .
generate phiHr = .
generate Hr = .

generate debtaxis =((_n-1)/50) in 1/51
	
local a = 0
while `a' <= 1  {
setx crisisfivebank `a' cumulateddebtlagged mean interactiondebtbank `a'*107.72
simqi, pr genpr(auto0 auto1)

_pctile auto0, p(2.5,97.5)
replace ploLr = r(r1) if debtaxis ==`a'
replace phiLr = r(r2) if debtaxis ==`a'
replace Lr = auto0 if debtaxis ==`a'

_pctile auto1, p(2.5,97.5)
replace ploHr = r(r1) if debtaxis ==`a'
replace phiHr = r(r2) if debtaxis ==`a'
replace Hr = auto1 if debtaxis ==`a'


drop auto0-auto1

local a = `a' + 0.01
}
sort debtaxis

graph twoway line Hr debtaxis, clwidth(medium) clcolor(blue) /*
*/ || line ploHr debtaxis, clpattern(dash) clwidth(thin) clcolor(black) /*
*/ || line phiHr debtaxis, clpattern(dash) clwidth(thin) clcolor(black)/* 
*/ ytitle(Pr) xtitle("") /*
*/ title("Marginal effect of Crisis over Democratization as Debt changes", size(4))


