********************************
* G. Schneider and F. Genovese *
*      "Smoke with Fire"       *
*        Web Appendix          *
********************************

use "../20121001SmokeWithFire.dta"


* 1. Descriptive tables

*Table 1: historical CBI changes and regime change
drop if x100change==.
list democratizationpolity country year if x100 <= 20 & democratizationpolity==1
list democratizationpolity country year if x100 > 51 & democratizationpolity==1
list autocratizationpolity country year if x100 <= 22 & autocratizationpolity==1
list autocratizationpolity country year if x100 >= 51 & autocratizationpolity==1

*Table 2 : historical CBI changes and speculative attacks (banking crises)
drop if x100change==.
list x100change country year if crisisfivebank ==1 & x100change>=51
*listtab x100change country year if crisisfivebank ==1 & x100change>=51 

list x100change country year if crisisfivebank ==1 & x100change<=-2
*listtab x100change country year if crisisfivebank ==1 & x100change<=-2 

list x100change country year if crisisfivebank ==0 & x100change>=51
list x100change country year if crisisfivebank ==0 & x100change<=-2

*Table 3: historical CBI changes and cumulated debt 
list x100change country year if cumulateddebtlagged>600 & x100change>=30
list x100 country year if cumulateddebtlagged>600 & x100<=10
list x100change country year if cumulateddebtlagged<100 & x100change>=40
list x100 country year if cumulateddebtlagged<50 & x100<=10

*** START FROM CLEARED DATASET!!! ***

*Table 4: historical speculatory attacks (banking crises) by regime change
list democratizationpolity country year if crisisfivebank==1 & democratizationpolity==1
list autocratizationpolity country year if crisisfivebank ==1 & autocratizationpolity==1

*Table 5: regime change and cumulated debt
list democratizationpolity country year if cumulateddebtlagged>600 & democratizationpolity==1
list democratizationpolity country year if cumulateddebtlagged<50 & democratizationpolity==1
list autocratizationpolity country year if cumulateddebtlagged>600 & autocratizationpolity==1
list autocratizationpolity country year if cumulateddebtlagged<50 & autocratizationpolity==1




* 2. Hausman test
xtreg x100change cumulateddebtlagged crisisfivebank crisisfivecurr, re
estimates store random
xtreg x100change cumulateddebtlagged crisisfivebank crisisfivecurr, fe
hausman . random

xtreg x100change cumulateddebtlagged crisisfivebank, re
estimates store random
xtreg x100change cumulateddebtlagged crisisfivebank, fe
hausman . random

xtlogit democratizationpolity cumulateddebtlagged crisisfivebank crisisfivecurr,  re nolog
estimates store re
xtlogit democratizationpolity cumulateddebtlagged crisisfivebank crisisfivecurr, fe nolog
estimates store fe
hausman fe re, eq(1:1)

xtlogit autocratizationpolity cumulateddebtlagged crisisfivebank crisisfivecurr,  re nolog
estimates store re
xtlogit autocratizationpolity cumulateddebtlagged crisisfivebank crisisfivecurr, fe nolog
estimates store fe
hausman re fe, alleqs constant

* The Hausman tests show that the prob>chi2 is below .05, therefore the fixed effects is preferable

/*
*** Models ***

tsset _ISO3N_ year

gen interactiondebtbank = crisisfivebank*cumulateddebtlagged
gen interactiondebtcurr = crisisfivecurr*cumulateddebtlagged
gen interactionbankcurr = crisisfivebank*crisisfivecurr
gen interactiondebtbankcurr = crisisfivebank*crisisfivecurr*cumulateddebtlagged

* Linear regressions of central bank independence
eststo M1a: xtreg x100change cumulateddebtlagged, fe
eststo M1b: xtreg x100change crisisfivebank, fe
eststo M1c: xtreg x100change crisisfivecurr, fe
eststo M2: xtreg x100change cumulateddebtlagged crisisfivebank interactiondebtbank, fe
eststo M3: xtreg x100change cumulateddebtlagged crisisfivecurr interactiondebtcurr, fe
eststo M4: xtreg x100change crisisfivebank crisisfivecurr interactionbankcurr, fe
eststo M5: xtreg x100change cumulateddebtlagged crisisfivebank crisisfivecurr interactiondebtbankcurr, fe
estimates table M1a M1b M1c M2 M3 M4 M5, star stats (N r2)
*esttab M1a M1b M1c M2 M3 M4 using Table1.doc

* Logit regressions of democratization
eststo N1a: xtlogit democratizationpolity cumulateddebtlagged, fe
eststo N1b: xtlogit democratizationpolity crisisfivebank, fe
eststo N1c: xtlogit democratizationpolity crisisfivecurr, fe
eststo N2: xtlogit democratizationpolity cumulateddebtlagged  crisisfivebank interactiondebtbank, fe
eststo N3: xtlogit democratizationpolity cumulateddebtlagged crisisfivecurr interactiondebtcurr, fe
eststo N4: xtlogit democratizationpolity crisisfivebank crisisfivecurr interactionbankcurr, fe
eststo N5: xtlogit democratizationpolity cumulateddebtlagged crisisfivebank crisisfivecurr interactiondebtbankcurr, fe
estimates table N1a N1b N1c N2 N3 N4 N5, star stats (N chi2)
*esttab N1a N1b N1c N2 N3 N4 using democratizationFE.doc

* Logit regressions of autocratization
eststo P1a: xtlogit autocratizationpolity cumulateddebtlagged, fe
eststo P1b: xtlogit autocratizationpolity crisisfivebank, fe
eststo P1c: xtlogit autocratizationpolity crisisfivecurr, fe
eststo P2: xtlogit autocratizationpolity cumulateddebtlagged  crisisfivebank interactiondebtbank, fe
eststo P3: xtlogit autocratizationpolity cumulateddebtlagged crisisfivecurr interactiondebtcurr, fe
eststo P4: xtlogit autocratizationpolity crisisfivebank crisisfivecurr interactionbankcurr, fe
eststo P5: xtlogit autocratizationpolity cumulateddebtlagged crisisfivebank crisisfivecurr interactiondebtbankcurr, fe
estimates table P1a P1b P1c P2 P3 P4, star stats (N chi2)
*esttab P1a P1b P1c P2 P3 P4 using autocratizationFE.doc
*/

* 3. Random Effects for xtlogit models

gen interactiondebtbank = crisisfivebank*cumulateddebtlagged
gen interactiondebtcurr = crisisfivecurr*cumulateddebtlagged
gen interactionbankcurr = crisisfivebank*crisisfivecurr
gen interactiondebtbankcurr = crisisfivebank*crisisfivecurr*cumulateddebtlagged

eststo N6base: xtlogit democratizationpolity cumulateddebtlagged crisisfivebank  crisisfivecurr , re
eststo N7: xtlogit democratizationpolity cumulateddebtlagged  crisisfivebank interactiondebtbank, re
eststo N8: xtlogit democratizationpolity cumulateddebtlagged crisisfivecurr interactiondebtcurr, re
eststo N9: xtlogit democratizationpolity cumulateddebtlagged crisisfivebank crisisfivecurr interactiondebtbankcurr, re
eststo N10: xtlogit democratizationpolity crisisfivebank crisisfivecurr interactionbankcurr, re
eststo N10complete: xtlogit democratizationpolity cumulateddebtlagged crisisfivebank crisisfivecurr interactiondebtbank interactiondebtcurr interactionbankcurr interactiondebtbankcurr, re
estimates table N6base N7 N8 N9 N10 N10complete, star stats (N chi2)
esttab N6base N7 N8 N9 N10 N10complete using democratizationRE.doc

eststo P6base: xtlogit autocratizationpolity cumulateddebtlagged crisisfivebank  crisisfivecurr , re
eststo P7: xtlogit autocratizationpolity cumulateddebtlagged  crisisfivebank interactiondebtbank, re
eststo P8: xtlogit autocratizationpolity cumulateddebtlagged crisisfivecurr interactiondebtcurr, re
eststo P9: xtlogit autocratizationpolity cumulateddebtlagged crisisfivebank crisisfivecurr interactiondebtbankcurr, re
eststo P10: xtlogit autocratizationpolity crisisfivebank crisisfivecurr interactionbankcurr, re
eststo P10complete: xtlogit autocratizationpolity cumulateddebtlagged crisisfivebank crisisfivecurr interactiondebtbank interactionbankcurr interactiondebtcurr interactiondebtbankcurr, re
estimates table P6base P7 P8 P9 P10 P10complete, star stats (N chi2)
esttab P6base P7 P8 P9 P10 P10complete using autocratizationRE.doc


* 4. Instrumental Variable analysis (GDP per capita, GDP growth and inflation here considered endogenous)

*corr cgdp7 growthgdpcaplag1 inflationchange

*First run the regressions where the macroeconomic indicators are included as independent variables
eststo M1: xtreg x100change cumulateddebtlagged crisisfivebank interactiondebtbank gdplag1 growthgdpcaplag1, fe
eststo M2: xtreg x100change cumulateddebtlagged crisisfivecurr interactiondebtcurr gdplag1 growthgdpcaplag1, fe
eststo M3: xtreg x100change cumulateddebtlagged crisisfivebank crisisfivecurr interactiondebtbankcurr gdplag1 growthgdpcaplag1, fe
estimates table  M1 M2 M3, star stats (N r2)
esttab M1 M2 M3 using Macro1.doc

eststo M4: xtlogit democratizationpolity cumulateddebtlagged  crisisfivebank interactiondebtbank gdplag1 growthgdpcaplag1, fe nolog
eststo M5: xtlogit democratizationpolity cumulateddebtlagged crisisfivecurr interactiondebtcurr gdplag1 growthgdpcaplag1, fe nolog
eststo M6: xtlogit democratizationpolity cumulateddebtlagged crisisfivebank crisisfivecurr interactiondebtbankcurr gdplag1 growthgdpcaplag1, fe nolog
estimates table  M4 M5 M6, star stats (N chi2)
esttab M4 M5 M6 using Macro2.doc

eststo M7: xtlogit autocratizationpolity cumulateddebtlagged  crisisfivebank interactiondebtbank gdplag1 growthgdpcaplag1, fe nolog
eststo M8: xtlogit autocratizationpolity cumulateddebtlagged crisisfivecurr interactiondebtcurr gdplag1 growthgdpcaplag1, fe nolog
eststo M9: xtlogit autocratizationpolity cumulateddebtlagged crisisfivebank crisisfivecurr interactiondebtbankcurr gdplag1 growthgdpcaplag1, fe nolog
estimates table  M7 M8 M9, star stats (N chi2)
esttab M7 M8 M9 using Macro3.doc

eststo Ma: xtreg x100change cumulateddebtlagged crisisfivebank crisisfivecurr gdplag1 growthgdpcaplag1 inflationchange, fe
eststo Mb: xtlogit democratizationpolity cumulateddebtlagged  crisisfivebank crisisfivecurr gdplag1 growthgdpcaplag1 inflationchange, fe nolog
eststo Mc: xtlogit autocratizationpolity cumulateddebtlagged  crisisfivebank crisisfivecurr gdplag1 growthgdpcaplag1 inflationchange, fe nolog
esttab Ma Mb Mc using Macro.doc

* Second run the I.V. regressions where the macroeconomic indicators are the instrumented variables
eststo S1: xtivreg x100change (gdplag1 = crisisfivecurr crisisfivebank cumulateddebtlagged), fe
eststo S2: xtivreg x100change (gdplag1 = crisisfivecurr crisisfivebank ), fe
eststo S3:xtivreg x100change (growthgdpcaplag1 = crisisfivecurr crisisfivebank cumulateddebtlagged), fe
eststo S4: xtivreg x100change (growthgdpcaplag1 = crisisfivebank cumulateddebtlagged), fe
eststo S5: xtivreg x100change (inflationchange = crisisfivecurr crisisfivebank cumulateddebtlagged), fe
eststo S6: xtivreg x100change (inflationchange = crisisfivecurr crisisfivebank), fe
estimates table  S1 S2 S3 S4 S5 S6, star stats (N chi2)
esttab S1  S3  S5 using IV1.doc

*eststo T1: ivprobit democratizationpolity (gdplag1 = crisisfivecurr crisisfivebank cumulateddebtlagged), first vce(cluster _ISO3N_) nolog
eststo T1: ivprobit democratizationpolity (cgdp7 = crisisfivecurr crisisfivebank cumulateddebtlagged), first vce(cluster _ISO3N_) nolog
eststo T2: ivprobit democratizationpolity (growthgdpcaplag1 = crisisfivecurr crisisfivebank cumulateddebtlagged), first vce(cluster _ISO3N_) nolog
eststo T3: ivprobit democratizationpolity (inflationchange = crisisfivecurr crisisfivebank cumulateddebtlagged), first vce(cluster _ISO3N_) nolog
eststo T4: ivprobit autocratizationpolity (cgdp7 = crisisfivecurr crisisfivebank cumulateddebtlagged), first vce(cluster _ISO3N_) nolog
eststo T5: ivprobit autocratizationpolity (growthgdpcaplag1 = crisisfivecurr crisisfivebank cumulateddebtlagged), first vce(cluster _ISO3N_) nolog
eststo T6: ivprobit autocratizationpolity (inflationchange = crisisfivecurr crisisfivebank cumulateddebtlagged), first vce(cluster _ISO3N_) nolog
* Insignificant link between macroeconomic variables and crises in explaining CBI, more significant link to explain democratization&autocratization
esttab T1 T2 T3  using IV2.doc
esttab T4 T5 T6 using IV3.doc

 xtivreg x100change (gdpfive = crisisfourcurr crisisfourbank cumulateddebtlaggedfour), fe
 xtivreg x100change (inflationfive = crisisfourcurr crisisfourbank cumulateddebtlaggedfour), fe
 xtivreg x100change (gdpgrowthfive = crisisfourcurr crisisfourbank cumulateddebtlaggedfour), fe

eststo T7: ivprobit democratizationpolity (gdpfive = crisisfourcurr crisisfourbank cumulateddebtlaggedfour), first vce(cluster _ISO3N_)
eststo T8: ivprobit autocratizationpolity (gdpfive = crisisfourcurr crisisfourbank cumulateddebtlaggedfour), first vce(cluster _ISO3N_)
eststo T9: ivprobit democratizationpolity (gdpgrowthfive = crisisfourcurr crisisfourbank cumulateddebtlaggedfour), first vce(cluster _ISO3N_)
eststo T10: ivprobit autocratizationpolity (gdpgrowthfive = crisisfourcurr crisisfourbank cumulateddebtlaggedfour), first vce(cluster _ISO3N_)
* Insignificant link between macroeconomic variables and crises when gdp and inflation are measured at the 5-year lag and crises at 4-year lag
esttab T7 T8 T9 T10 using IV4.doc

* 5. Analysis with democratization and autocratization at higher Polity score (+/-4)

eststo S1a: xtlogit democratizationpolityfour cumulateddebtlagged, fe
eststo S1b: xtlogit democratizationpolityfour crisisfivebank, fe
eststo S1c: xtlogit democratizationpolityfour crisisfivecurr, fe
eststo S2a: xtlogit democratizationpolityfour cumulateddebtlagged  crisisfivebank interactiondebtbank, fe
eststo S3a: xtlogit democratizationpolityfour cumulateddebtlagged crisisfivecurr interactiondebtcurr, fe
eststo S3b: xtlogit democratizationpolityfour crisisfivebank crisisfivecurr interactionbankcurr, fe
eststo S4a: xtlogit democratizationpolityfour cumulateddebtlagged crisisfivebank crisisfivecurr interactiondebtbankcurr, fe
estimates table S1a S1b S1c S2a S3a S3b S4a, star stats (N chi2)
esttab S1a S1b S1c S2a S3a S3b S4a using Demofour.doc

gen autocratizationpolityfour = .
replace autocratizationpolityfour = 0 if polity2transformedchange>=-4
replace autocratizationpolityfour = . if polity2transformedchange==.
replace autocratizationpolityfour = 1 if polity2transformedchange < -4

eststo T1a: xtlogit autocratizationpolityfour cumulateddebtlagged, fe
eststo T1b: xtlogit autocratizationpolity crisisfivebank, fe
eststo T1c: xtlogit autocratizationpolity crisisfivecurr, fe
eststo T2a: xtlogit autocratizationpolity cumulateddebtlagged  crisisfivebank interactiondebtbank, fe
eststo T3a: xtlogit autocratizationpolity cumulateddebtlagged crisisfivecurr interactiondebtcurr, fe
eststo T3b: xtlogit autocratizationpolityfour crisisfivebank crisisfivecurr interactionbankcurr, fe
eststo T4a: xtlogit autocratizationpolity cumulateddebtlagged crisisfivebank crisisfivecurr interactiondebtbankcurr, fe
estimates table T1a T1b T1c T2a T3a T3b T4a, star stats (N chi2)
esttab T1a T1b T1c T2a T3a T3b T4a using Autofour.doc

* 6.  Control for spill-over effects: regressions with dummies for regions' historical events 
* The events: crisisasia1990s for the Asian crisis (1997-2001); crisiswestenergy1970s for oil crisis in Western economies (1973-1978); crisislatinamerica1980s for L.A. crisis (1982-1987); and crisisUSSR1980s for the end of the Soviet Union (1986-1991)

eststo Control1: xtreg x100change cumulateddebtlagged crisisfivebank interactiondebtbank crisisasia1990s crisiswestenergy1970s crisislatinamerica1980s crisisUSSR1980s, fe
eststo Control2: xtreg x100change cumulateddebtlagged crisisfivecurr interactiondebtcurr crisisasia1990s crisiswestenergy1970s crisislatinamerica1980s crisisUSSR1980s, fe
eststo Control3: xtreg x100change crisisfivecurr crisisfivebank interactionbankcurr crisisasia1990s crisiswestenergy1970s crisislatinamerica1980s crisisUSSR1980s, fe
eststo Control4: xtreg x100change cumulateddebtlagged crisisfivebank crisisfivecurr interactiondebtbankcurr crisisasia1990s crisiswestenergy1970s crisislatinamerica1980s crisisUSSR1980s, fe
estimates table  Control1 Control2 Control3 Control4, star stats (N r2)
esttab Control1 Control2 Control3 Control4 using Control1.doc

eststo Control5: xtlogit democratizationpolity cumulateddebtlagged  crisisfivebank interactiondebtbank crisisasia1990s crisiswestenergy1970s crisislatinamerica1980s crisisUSSR1980s, fe nolog
eststo Control6: xtlogit democratizationpolity cumulateddebtlagged crisisfivecurr interactiondebtcurr crisisasia1990s crisiswestenergy1970s crisislatinamerica1980s crisisUSSR1980s, fe nolog
eststo Control7: xtlogit democratizationpolity crisisfivebank crisisfivecurr interactionbankcurr crisisasia1990s crisiswestenergy1970s crisislatinamerica1980s crisisUSSR1980s, fe nolog
eststo Control8: xtlogit democratizationpolity cumulateddebtlagged crisisfivebank crisisfivecurr interactiondebtbankcurr crisisasia1990s crisiswestenergy1970s crisislatinamerica1980s crisisUSSR1980s, fe nolog
estimates table  Control5 Control6 Control7 Control8, star stats (N chi2)
esttab Control5 Control6 Control7 Control8 using Control2.doc

eststo Control9: xtlogit autocratizationpolity cumulateddebtlagged  crisisfivebank interactiondebtbank crisisasia1990s crisiswestenergy1970s crisislatinamerica1980s crisisUSSR1980s, fe nolog
eststo Control10: xtlogit autocratizationpolity cumulateddebtlagged crisisfivecurr interactiondebtcurr crisisasia1990s crisiswestenergy1970s crisislatinamerica1980s crisisUSSR1980s, fe nolog
eststo Control11: xtlogit autocratizationpolity crisisfivebank crisisfivecurr interactionbankcurr crisisasia1990s crisiswestenergy1970s crisislatinamerica1980s crisisUSSR1980s, fe nolog
eststo Control12: xtlogit autocratizationpolity cumulateddebtlagged crisisfivebank crisisfivecurr interactiondebtbankcurr crisisasia1990s crisiswestenergy1970s crisislatinamerica1980s crisisUSSR1980s, fe nolog
estimates table  Control9 Control10 Control11 Control12, star stats (N chi2)
esttab Control9 Control10  Control11 Control12 using Control3.doc



* 7. Check on first occurrence of CBI observations: regressions of crises variables on first observations only

by country (year), sort: gen noccur = sum(x100change)

by country: gen byte first = noccur != . & noccur != 0  & noccur[_n - 1] != noccur

* To show the country-year cases,
* list noccur if first==1
* To identify the initial year per country,
* by country, sort: egen firsttime = min(cond(x100change != ., year, .))

drop if first!=1

tsset _ISO3N_ year


eststo CBI1a: xtreg x100change cumulateddebtlagged, fe
eststo CBI1b: xtreg x100change crisisfivebank, fe
eststo CBI1c: xtreg x100change crisisfivecurr, fe
eststo CBI2: xtreg x100change cumulateddebtlagged crisisfivebank interactiondebtbank, fe
eststo CBI3: xtreg x100change cumulateddebtlagged crisisfivecurr interactiondebtcurr, fe
eststo CBI4: xtreg x100change crisisfivebank crisisfivecurr interactionbankcurr, fe
eststo CBI5: xtreg x100change cumulateddebtlagged crisisfivebank crisisfivecurr interactiondebtbankcurr, fe
estimates table CBI1a CBI1b CBI1c CBI2 CBI3 CBI4 CBI5, star stats (N r2)
esttab CBI2 CBI3 CBI4 CBI5 using CBI.doc

